@@ -1,6 +1,6 @@
 ;;; notmuch-indicator.el --- Display mode line indicator with notmuch-count(1) output -*- lexical-binding: t -*-
 
-;; Copyright (C) 2022-2024  Free Software Foundation, Inc.
+;; Copyright (C) 2022-2026  Free Software Foundation, Inc.
 
 ;; Author: Protesilaos Stavrou <info@protesilaos.com>
 ;; Maintainer: Protesilaos Stavrou <info@protesilaos.com>
@@ -169,6 +169,8 @@ option `notmuch-indicator-refresh-count'."
   "Return `notmuch' configuration file."
   (catch 'found
     (dolist (path '("$XDG_CONFIG_HOME/notmuch/$NOTMUCH_PROFILE/config"
+                    "$HOME/.config/notmuch/$NOTMUCH_PROFILE/config"
+                    "$HOME/.config/notmuch/default/config"
                     "$HOME/.notmuch-config.$NOTMUCH_PROFILE"
                     "$HOME/.notmuch-config"))
       (when-let* ((config (substitute-env-vars path))
